==> qmmp_0.5.5.orig.tar.gz: qmmp-0.5.5/src/plugins/General/hotkey/translations/hotkey_plugin_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_TW">
<context>
    <name>HotkeyDialog</name>
    <message>
        <location filename="../hotkeydialog.ui" line="14"/>
        <source>Modify Shortcut</source>
        <translation>修改熱鍵</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="32"/>
        <source>Press the key combination you want to assign</source>
        <translation>請按您想指定的組合鍵</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="52"/>
        <source>Clear</source>
        <translation>清除</translation>
    </message>
</context>
<context>
    <name>HotkeyFactory</name>
    <message>
        <location filename="../hotkeyfactory.cpp" line="30"/>
        <source>Global Hotkey Plugin</source>
        <translation>全局熱鍵插件</translation>
    </message>
    <message>
        <location filename="../hotkeyfactory.cpp" line="50"/>
        <source>About Global Hotkey Plugin</source>
        <translation>關於全局熱鍵插件</translation>
    </message>
    <message>
        <location filename="../hotkeyfactory.cpp" line="51"/>
        <source>Qmmp Global Hotkey Plugin</source>
        <translation>Qmmp 全局熱鍵插件</translation>
    </message>
    <message>
        <location filename="../hotkeyfactory.cpp" line="52"/>
        <source>This plugin adds support for multimedia keys or global key combinations</source>
        <translation>此插件支援添加多媒體熱鍵與全局熱鍵</translation>
    </message>
    <message>
        <location filename="../hotkeyfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.cpp" line="42"/>
        <source>Play</source>
        <translation>播放</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="43"/>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="44"/>
        <source>Pause</source>
        <translation>暫停</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="45"/>
        <source>Play/Pause</source>
        <translation>播放/暫停</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="46"/>
        <source>Next</source>
        <translation>下一曲</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="47"/>
        <source>Previous</source>
        <translation>上一曲</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="48"/>
        <source>Show/Hide</source>
        <translation>察看/隱藏</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="49"/>
        <source>Volume +</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="50"/>
        <source>Volume -</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Global Hotkey Plugin Settings</source>
        <translation>全局熱鍵插件設置</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="42"/>
        <source>Action</source>
        <translation>動作</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="47"/>
        <source>Shortcut</source>
        <translation>熱鍵</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Reset</source>
        <translation>重置</translation>
    </message>
</context>
</TS>

==> qmmp_0.7.4.orig.tar.gz: qmmp-0.7.4/src/plugins/General/hotkey/translations/hotkey_plugin_zh_TW.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_TW">
<context>
    <name>HotkeyDialog</name>
    <message>
        <location filename="../hotkeydialog.ui" line="14"/>
        <source>Modify Shortcut</source>
        <translation>修改熱鍵</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="32"/>
        <source>Press the key combination you want to assign</source>
        <translation>請按您想指定的組合鍵</translation>
    </message>
    <message>
        <location filename="../hotkeydialog.ui" line="52"/>
        <source>Clear</source>
        <translation>清除</translation>
    </message>
</context>
<context>
    <name>HotkeyFactory</name>
    <message>
        <location filename="../hotkeyfactory.cpp" line="30"/>
        <source>Global Hotkey Plugin</source>
        <translation>全局熱鍵插件</translation>
    </message>
    <message>
        <location filename="../hotkeyfactory.cpp" line="50"/>
        <source>About Global Hotkey Plugin</source>
        <translation>關於全局熱鍵插件</translation>
    </message>
    <message>
        <location filename="../hotkeyfactory.cpp" line="51"/>
        <source>Qmmp Global Hotkey Plugin</source>
        <translation>Qmmp 全局熱鍵插件</translation>
    </message>
    <message>
        <location filename="../hotkeyfactory.cpp" line="52"/>
        <source>This plugin adds support for multimedia keys or global key combinations</source>
        <translation>此插件支援添加多媒體熱鍵與全局熱鍵</translation>
    </message>
    <message>
        <location filename="../hotkeyfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>作者：Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.cpp" line="36"/>
        <source>Play</source>
        <translation>播放</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="37"/>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="38"/>
        <source>Pause</source>
        <translation>暫停</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="39"/>
        <source>Play/Pause</source>
        <translation>播放/暫停</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="40"/>
        <source>Next</source>
        <translation>下一曲</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="41"/>
        <source>Previous</source>
        <translation>上一曲</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="42"/>
        <source>Show/Hide</source>
        <translation>察看/隱藏</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="43"/>
        <source>Volume +</source>
        <translation>音量 +</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="44"/>
        <source>Volume -</source>
        <translation>音量 -</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="45"/>
        <source>Forward 5 seconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="46"/>
        <source>Rewind 5 seconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="47"/>
        <source>Jump to track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Global Hotkey Plugin Settings</source>
        <translation>全局熱鍵插件設置</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="42"/>
        <source>Action</source>
        <translation>動作</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="47"/>
        <source>Shortcut</source>
        <translation>熱鍵</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Reset</source>
        <translation>重置</translation>
    </message>
</context>
</TS>
